#!/bin/bash

#if [[ "$EUID" -ne 0 ]]; then
#	echo -e "Sorry, you need to run this as root"
#	exit 1
#fi

BASE_DIR="$(cd "$(dirname "$0")"; pwd)";

# Variables
INSTALL_USER=`whoami`
NGINX_INSTALL_DIR=$1
SVR_INSTALL_DIR=$2
DOCUMENT_ROOT=$3
HTTP_PORT=$4
SSL_PORT=$5

SOURCE_DIR=${BASE_DIR}/source_files

NGINX_VERSION=1.15.8
NGINX_INSTALL_FILE=nginx-${NGINX_VERSION}

INSTALL_DATE=`date +%Y%m%d_%H%M%S`

if [ "x$1" = "x" ]; then
    echo "#################################################"
    echo "[WARN] Empty input nginx home directory. Use default value." >> install.log.$INSTALL_DATE
    echo "[WARN] Empty input nginx home directory. Use default value."
    echo "#################################################" 
    exit 1;
fi

if [ "x$2" = "x" ]; then
    echo "#################################################"
    echo "[WARN] Empty input install directory. Use default value." >> install.log.$INSTALL_DATE
    echo "[WARN] Empty input install directory. Use default value."
    echo "#################################################"

    SVR_INSTALL_DIR="/opt/WASup/servers/nginx-svr-1.15"
    echo "[ SVR_INSTALL_DIR ] is $SVR_INSTALL_DIR"
fi

if [ "x$3" = "x" ]; then
    DOCUMENT_ROOT=$SVR_INSTALL_DIR/html
fi

if [ "x$4" = "x" ]; then
    HTTP_PORT=80
fi

if [ "x$5" = "x" ]; then
    SSL_PORT=443
fi

clear

# Cleanup
# The directory should be deleted at the end of the script, but in case it fails
mkdir -p ${SVR_INSTALL_DIR}/logs
mkdir -p ${SVR_INSTALL_DIR}/tmp/client
mkdir -p ${SVR_INSTALL_DIR}/tmp/proxy
mkdir -p ${SVR_INSTALL_DIR}/tmp/fastcgi

echo "BASE_DIR=$BASE_DIR"
echo "SOURCE_DIR=$SOURCE_DIR"
echo "NGINX_INSTALL_DIR=$NGINX_INSTALL_DIR"
echo "SVR_INSTALL_DIR=$SVR_INSTALL_DIR"
echo "DOCUMENT_ROOT=$DOCUMENT_ROOT"
echo "HTTP_PORT=$HTTP_PORT"
echo "SSL_PORT=$SSL_PORT"


############ Default Template Copy ##############
cp -fR $SOURCE_DIR/bin ${SVR_INSTALL_DIR}
cp -fR $SOURCE_DIR/conf ${SVR_INSTALL_DIR}
cp -fR $SOURCE_DIR/conf.d ${SVR_INSTALL_DIR}/conf.d

if [ ! -d $DOCUMENT_ROOT ] ; then
    mkdir -p $DOCUMENT_ROOT

    if [ -f $NGINX_INSTALL_DIR/html/index.html ] ; then
        cp $NGINX_INSTALL_DIR/html/*.html $DOCUMENT_ROOT/
    fi
fi

############ Nginx Server Directory Replace ########
sh ${BASE_DIR}/replace.sh ${NGINX_INSTALL_DIR} ${SVR_INSTALL_DIR} ${DOCUMENT_ROOT} ${HTTP_PORT} ${SSL_PORT}
############ Nginx Directory Replace ########
